@@ -22,7 +22,7 @@ def test_app_install(appcenter, app_name, app_version):
 
         app.install()
 
-        app.verify(joined=False)
+        app.verify()
 
         lo = get_ldap_connection()
         print(lo.searchDn(filter=f'(&(cn={app_name[:5]}-*)(objectClass=univentionMemberServer)(!(aRecord=*))(!(macAddress=*)))', unique=True, required=True))
