@@ -1,5 +1,4 @@
 #!/usr/share/ucs-test/runner /usr/share/ucs-test/playwright
-# -*- coding: utf-8 -*-
 ## desc: |
 ##  Test favorite modules
 ## roles-not:
@@ -11,7 +10,6 @@
 
 import re
 import time
-from typing import List
 
 from playwright.sync_api import Locator, Page, expect
 
@@ -91,7 +89,7 @@ def check_module_is_visible(page: Page, moduleid: str):
     expect(locator).to_be_visible()
 
 
-def get_default_favorites(ucr) -> List[str]:
+def get_default_favorites(ucr) -> list[str]:
     default_favorites_string = ucr.get('umc/web/favorites/default')
 
     if not utils.package_installed('univention-management-console-module-welcome'):
@@ -117,7 +115,7 @@ def re_add_default_favorites(page: Page, ucr):
     check_removing_default_favorites(page)
 
     page.locator('.umcModuleSearchToggleButton').click()
-    page.locator('.umcModuleSearch input.dijitInputInner').type('*')
+    page.locator('.umcModuleSearch input.dijitInputInner').press_sequentially('*')
     for favorite in get_default_favorites(ucr):
         locator = get_locator_for_module_by_moduleid(page, favorite)
         locator.click(button='right')
